<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>InfoPositionRel</name>
    <message>
        <location filename="../InfoPositionRelInit.js" line="+2"/>
        <source>&amp;Relative Position</source>
        <translation>Położenie &amp;względne</translation>
    </message>
</context>
</TS>
